*seddy* - SWF management
========================

Multi-workflow SWF decider and workflow management service.


Installation
------------

.. code-block:: shell

   pip3 install seddy


Documentation
-------------

.. toctree::
   :maxdepth: 1

   API Reference <seddy>
   cli
   io
   specs
   tutorial

* :ref:`genindex`
